summaryrefslogtreecommitdiff
path: root/zwgc/X_fonts.h
diff options
context:
space:
mode:
Diffstat (limited to 'zwgc/X_fonts.h')
-rw-r--r--zwgc/X_fonts.h5
1 files changed, 2 insertions, 3 deletions
diff --git a/zwgc/X_fonts.h b/zwgc/X_fonts.h
index 62469c8..8e40ed8 100644
--- a/zwgc/X_fonts.h
+++ b/zwgc/X_fonts.h
@@ -31,7 +31,7 @@
#define LARGE_SIZE 2
/*
* XFontStruct *get_font(string family; int size, face)
* Requires: size is one of SMALL_SIZE, MEDIUM_SIZE, LARGE_SIZE and
* face is one of ROMAN_FACE, BOLD_FACE, ITALIC_FACE,
* BOLDITALIC_FACE.
@@ -41,7 +41,6 @@
* specified by default.medium.roman is used. <<<>>>
*/
-extern XFontStruct *get_font(Display *, string, string, int, int);
-extern XFontStruct *get_fontst_from_fid(Font);
+extern XFontSet get_font(Display *, string, string, int, int);
#endif
@@ -31,7 +31,7 @@
#define LARGE_SIZE 2
/*
- * XFontStruct *get_font(string family; int size, face)
+ * XFontSet get_font(string family; int size, face)
* Requires: size is one of SMALL_SIZE, MEDIUM_SIZE, LARGE_SIZE and
* face is one of ROMAN_FACE, BOLD_FACE, ITALIC_FACE,